@@ -2,7 +2,7 @@ use super::Director;
 use crate::fs;
 use crate::fs::Stub;
 use getset::Getters;
-use glob::glob;
+use nu_glob::glob;
 use std::path::{Path, PathBuf};
 use std::str;
 use tempfile::{tempdir, TempDir};
@@ -78,7 +78,8 @@ impl<'a> Playground<'a> {
         std::fs::create_dir(PathBuf::from(&nuplay_dir)).expect("can not create directory");
 
         let fixtures = fs::fixtures();
-        let fixtures = nu_path::canonicalize(fixtures.clone()).unwrap_or_else(|e| {
+        let cwd = std::env::current_dir().expect("Could not get current working directory.");
+        let fixtures = nu_path::canonicalize_with(fixtures.clone(), cwd).unwrap_or_else(|e| {
             panic!(
                 "Couldn't canonicalize fixtures path {}: {:?}",
                 fixtures.display(),
@@ -97,15 +98,18 @@ impl<'a> Playground<'a> {
 
         let playground_root = playground.root.path();
 
-        let test = nu_path::canonicalize(playground_root.join(topic)).unwrap_or_else(|e| {
-            panic!(
-                "Couldn't canonicalize test path {}: {:?}",
-                playground_root.join(topic).display(),
-                e
-            )
-        });
+        let cwd = std::env::current_dir().expect("Could not get current working directory.");
+        let test =
+            nu_path::canonicalize_with(playground_root.join(topic), cwd).unwrap_or_else(|e| {
+                panic!(
+                    "Couldn't canonicalize test path {}: {:?}",
+                    playground_root.join(topic).display(),
+                    e
+                )
+            });
 
-        let root = nu_path::canonicalize(playground_root).unwrap_or_else(|e| {
+        let cwd = std::env::current_dir().expect("Could not get current working directory.");
+        let root = nu_path::canonicalize_with(playground_root, cwd).unwrap_or_else(|e| {
             panic!(
                 "Couldn't canonicalize tests root path {}: {:?}",
                 playground_root.display(),
